dice\_ml package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   dice_ml.data_interfaces
   dice_ml.explainer_interfaces
   dice_ml.model_interfaces
   dice_ml.schema
   dice_ml.utils

Submodules
----------

dice\_ml.constants module
-------------------------

.. automodule:: dice_ml.constants
   :members:
   :undoc-members:
   :show-inheritance:

dice\_ml.counterfactual\_explanations module
--------------------------------------------

.. automodule:: dice_ml.counterfactual_explanations
   :members:
   :undoc-members:
   :show-inheritance:

dice\_ml.data module
--------------------

.. automodule:: dice_ml.data
   :members:
   :undoc-members:
   :show-inheritance:

dice\_ml.dice module
--------------------

.. automodule:: dice_ml.dice
   :members:
   :undoc-members:
   :show-inheritance:

dice\_ml.diverse\_counterfactuals module
----------------------------------------

.. automodule:: dice_ml.diverse_counterfactuals
   :members:
   :undoc-members:
   :show-inheritance:

dice\_ml.model module
---------------------

.. automodule:: dice_ml.model
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dice_ml
   :members:
   :undoc-members:
   :show-inheritance:
